@@ -1,7 +1,7 @@
-version = "1.27"
+version = "1.29"
 
 # tools
-dblatex = '/usr/bin/dblatex'
+dblatex = ''
 fop = ''
 highlight = '/usr/bin/source-highlight'
 highlight_options = '-t4 -s$SRC_LANG -cstyle.css --no-doc -i'
@@ -9,7 +9,7 @@ pkg_config = '/usr/bin/pkg-config'
 xsltproc = '/usr/bin/xsltproc'
 
 # configured directories
-prefix = '/usr'
+prefix = '/usr/local'
 datarootdir = "${prefix}/share".replace('${prefix}', prefix)
 datadir = "${datarootdir}".replace('${datarootdir}', datarootdir)
 
