@@ -21,9 +21,6 @@
 
 ''"Fix cross-references in the HTML documentation.''"
 
-# Support both Python 2 and 3
-from __future__ import print_function
-
 import logging
 import os
 import re
@@ -49,10 +46,6 @@ NoLinks = {
     'unsigned',
     'va-list',
     'void',
-    'GBoxed',
-    'GEnum',
-    'GFlags',
-    'GInterface'
 }
 
 
@@ -93,6 +86,11 @@ def LoadIndicies(module_dir, html_dir, extra_dirs):
         if dir != html_dir:
             logging.info('Scanning GLib directory: %s', dir)
             ScanIndices(dir, (re.search(prefix_match, dir) is None), dir_cache)
+    else:
+        NoLinks.add('GBoxed')
+        NoLinks.add('GEnum')
+        NoLinks.add('GFlags')
+        NoLinks.add('GInterface')
 
     path = os.environ.get('GNOME2_PATH')
     if path:
@@ -182,7 +180,7 @@ def ReadDevhelp(file, use_absolute_links):
 
     logging.info('Scanning index file=%s, absolute=%d, dir=%s', file, use_absolute_links, dir)
 
-    for line in common.open_text(file):
+    for line in open(file, 'r', encoding='utf-8'):
         m = re.search(r' link="([^#]*)#([^"]*)"', line)
         if m:
             link = m.group(1) + '#' + m.group(2)
@@ -192,7 +190,7 @@ def ReadDevhelp(file, use_absolute_links):
 
 def ReadSections(module):
     """We don't warn on missing links to non-public sysmbols."""
-    for line in common.open_text(module + '-sections.txt'):
+    for line in open(module + '-sections.txt', 'r', encoding='utf-8'):
         m1 = re.search(r'^<SUBSECTION\s*(.*)>', line)
         if line.startswith('#') or line.strip() == '':
             continue
@@ -227,7 +225,7 @@ def FixCrossReferences(module_dir, module, src_lang):
 def FixHTMLFile(src_lang, module, file):
     logging.info('Fixing file: %s', file)
 
-    content = common.open_text(file).read()
+    content = open(file, 'r', encoding='utf-8').read()
 
     if config.highlight:
         # FIXME: ideally we'd pass a clue about the example language to the highligher
@@ -271,62 +269,88 @@ def FixHTMLFile(src_lang, module, file):
 
     new_file = file + '.new'
     content = '\n'.join(lines)
-    with common.open_text(new_file, 'w') as h:
+    with open(new_file, 'w', encoding='utf-8') as h:
         h.write(content)
 
     os.unlink(file)
     os.rename(new_file, file)
 
 
-def MakeXRef(module, file, line, id, text):
+def GetXRef(id):
     href = Links.get(id)
+    if href:
+        return (id, href)
 
     # This is a workaround for some inconsistency we have with CreateValidSGMLID
-    if not href and ':' in id:
-        href = Links.get(id.replace(':', '--'))
+    if ':' in id:
+        tid = id.replace(':', '--')
+        href = Links.get(tid)
+        if href:
+            return (tid, href)
+
     # poor mans plural support
-    if not href and id.endswith('s'):
+    if id.endswith('s'):
         tid = id[:-1]
         href = Links.get(tid)
-        if not href:
-            href = Links.get(tid + '-struct')
-    if not href:
-        href = Links.get(id + '-struct')
+        if href:
+            return (tid, href)
+        tid += '-struct'
+        href = Links.get(tid)
+        if href:
+            return (tid, href)
+
+    tid = id + '-struct'
+    href = Links.get(tid)
+    if href:
+        return (tid, href)
+
+    return (id, None)
+
+
+def ReportBadXRef(file, line, id, text):
+    logging.info('no link for: id=%s, linktext=%s', id, text)
+
+    # don't warn multiple times and also skip blacklisted (ctypes)
+    if id in NoLinks:
+        return
+    # if it's a function, don't warn if it does not contain a "_"
+    # (transformed to "-")
+    # - gnome coding style would use '_'
+    # - will avoid wrong warnings for ansi c functions
+    if re.search(r' class=\"function\"', text) and '-' not in id:
+        return
+    # if it's a 'return value', don't warn (implicitly created link)
+    if re.search(r' class=\"returnvalue\"', text):
+        return
+    # if it's a 'type', don't warn if it starts with lowercase
+    # - gnome coding style would use CamelCase
+    if re.search(r' class=\"type\"', text) and id[0].islower():
+        return
+    # don't warn for self links
+    if text == id:
+        return
+
+    common.LogWarning(file, line, 'no link for: "%s" -> (%s).' % (id, text))
+    NoLinks.add(id)
+
+
+def MakeRelativeXRef(module, href):
+    # if it is a link to same module, remove path to make it work uninstalled
+    m = re.search(r'^\.\./' + module + '/(.*)$', href)
+    if m:
+        href = m.group(1)
+    return href
+
+
+def MakeXRef(module, file, line, id, text):
+    href = GetXRef(id)[1]
 
     if href:
-        # if it is a link to same module, remove path to make it work uninstalled
-        m = re.search(r'^\.\./' + module + '/(.*)$', href)
-        if m:
-            href = m.group(1)
-            logging.info('Fixing link to uninstalled doc: %s, %s, %s', id, href, text)
-        else:
-            logging.info('Fixing link: %s, %s, %s', id, href, text)
+        href = MakeRelativeXRef(module, href)
+        logging.info('Fixing link: %s, %s, %s', id, href, text)
         return "<a href=\"%s\">%s</a>" % (href, text)
     else:
-        logging.info('no link for: %s, %s', id, text)
-
-        # don't warn multiple times and also skip blacklisted (ctypes)
-        if id in NoLinks:
-            return text
-        # if it's a function, don't warn if it does not contain a "_"
-        # (transformed to "-")
-        # - gnome coding style would use '_'
-        # - will avoid wrong warnings for ansi c functions
-        if re.search(r' class=\"function\"', text) and '-' not in id:
-            return text
-        # if it's a 'return value', don't warn (implicitly created link)
-        if re.search(r' class=\"returnvalue\"', text):
-            return text
-        # if it's a 'type', don't warn if it starts with lowercase
-        # - gnome coding style would use CamelCase
-        if re.search(r' class=\"type\"', text) and id[0].islower():
-            return text
-        # don't warn for self links
-        if text == id:
-            return text
-
-        common.LogWarning(file, line, 'no link for: "%s" -> (%s).' % (id, text))
-        NoLinks.add(id)
+        ReportBadXRef(file, line, id, text)
         return text
 
 
@@ -385,7 +409,7 @@ def HighlightSourceVim(src_lang, type, source):
         script += "%s -n -e -u NONE -T xterm >/dev/null" % config.highlight
         subprocess.check_call([script], shell=True)
 
-        highlighted_source = common.open_text(temp_source_file + ".html").read()
+        highlighted_source = open(temp_source_file + ".html", 'r', encoding='utf-8').read()
         highlighted_source = re.sub(r'.*<pre\b[^>]*>\n', '', highlighted_source, flags=re.DOTALL)
         highlighted_source = re.sub(r'</pre>.*', '', highlighted_source, flags=re.DOTALL)
 
