@@ -33,9 +33,6 @@ This second list file is typically copied to '$MODULE-sections.txt' and
 organized into sections ready to output the XML pages.
 """
 
-from __future__ import print_function
-from six import iteritems, iterkeys
-
 import logging
 import os
 import re
@@ -49,7 +46,7 @@ seen_headers = {}
 
 
 def Run(options):
-    # logging.basicConfig(level=logging.INFO)
+    logging.info('options: %s', str(options.__dict__))
 
     if not os.path.isdir(options.output_dir):
         os.mkdir(options.output_dir)
@@ -77,16 +74,16 @@ def Run(options):
     for dir in options.source_dir:
         ScanHeaders(dir, section_list, decl_list, get_types, options)
 
-    with common.open_text(new_decl_list, 'w') as f:
-        for section in sorted(iterkeys(section_list)):
+    with open(new_decl_list, 'w', encoding='utf-8') as f:
+        for section in sorted(section_list.keys()):
             f.write(section_list[section])
 
-    with common.open_text(new_decl, 'w') as f:
+    with open(new_decl, 'w', encoding='utf-8') as f:
         for decl in decl_list:
             f.write(decl)
 
     if options.rebuild_types:
-        with common.open_text(new_types, 'w') as f:
+        with open(new_types, 'w', encoding='utf-8') as f:
             for func in sorted(get_types):
                 f.write(func + '\n')
 
@@ -113,7 +110,7 @@ def Run(options):
     # because EXTRA_DIST in gtk-doc.make requires it.
     overrides_file = base_filename + '-overrides.txt'
     if not os.path.exists(overrides_file):
-        open(overrides_file, 'w').close()
+        open(overrides_file, 'w', encoding='utf-8').close()
 
 
 #
@@ -226,9 +223,9 @@ def ScanHeader(input_file, section_list, decl_list, get_types, options):
 
     logging.info('Scanning %s', input_file)
 
-    for line in common.open_text(input_file):
+    for line in open(input_file, 'r', encoding='utf-8'):
         # If this is a private header, skip it.
-        if re.search(r'%^\s*/\*\s*<\s*private_header\s*>\s*\*/', line):
+        if re.search(r'^\s*/\*\s*<\s*private_header\s*>\s*\*/', line):
             return
 
         # Skip to the end of the current comment.
@@ -604,7 +601,7 @@ def ScanHeader(input_file, section_list, decl_list, get_types, options):
                     symbol = re.sub(r'\s*\n', '', symbol, flags=re.MULTILINE)
                     logging.info('Function (6): "%s", Returns: "%s"', symbol, ret_type)
 
-            #} elsif (m/^extern\s+/) {
+            # } elsif (m/^extern\s+/) {
                 # print "DEBUG: Skipping extern: $_"
 
             # STRUCTS
@@ -692,7 +689,7 @@ def ScanHeader(input_file, section_list, decl_list, get_types, options):
                 if internal == 0:
                     decl = re.sub(r'/\*.*?\*/', '', decl, flags=re.MULTILINE)   # remove comments.
                     decl = re.sub(r'\s*\n\s*(?!$)', ' ', decl, flags=re.MULTILINE)
-                                  # consolidate whitespace at start/end of lines.
+                    # consolidate whitespace at start/end of lines.
                     decl = decl.strip()
                     ret_type = re.sub(r'/\*.*?\*/', '', ret_type)               # remove comments in ret type.
                     if AddSymbolToList(slist, symbol):
@@ -773,7 +770,7 @@ def ScanHeader(input_file, section_list, decl_list, get_types, options):
         previous_line = line
 
     # print remaining forward declarations
-    for symbol in sorted(iterkeys(forward_decls)):
+    for symbol in sorted(forward_decls.keys()):
         if forward_decls[symbol]:
             AddSymbolToList(slist, symbol)
             decl_list.append(forward_decls[symbol])
@@ -885,9 +882,9 @@ def AddSymbolToList(slist, symbol):
         symbol: The symbol to add to the list.
     """
     if symbol in slist:
-         # logging.info('Symbol %s already in list. skipping', symbol)
-         # we return False to skip outputting another entry to -decl.txt
-         # this is to avoid redeclarations (e.g. in conditional sections).
+        # logging.info('Symbol %s already in list. skipping', symbol)
+        # we return False to skip outputting another entry to -decl.txt
+        # this is to avoid redeclarations (e.g. in conditional sections).
         return False
     slist.append(symbol)
     return True
